@@ -3,7 +3,7 @@
 # Crypt::HashCash::Client - Client for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Client.pm v1.124 Mon Jun 19 15:51:59 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Client.pm v1.126 Sat Jun 24 02:15:17 PDT 2017 $
 
 package Crypt::HashCash::Client;
 
@@ -23,7 +23,7 @@ use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.124 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.126 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -257,8 +257,8 @@ Crypt::HashCash::Client - Client for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.124 $
- $Date: Mon Jun 19 15:51:59 PDT 2017 $
+ $Revision: 1.126 $
+ $Date: Sat Jun 24 02:15:17 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -318,7 +318,7 @@ Creates and returns a new Crypt::HashCash::Client object.
 
 =head1 SEE ALSO
 
-=head2 L<www.hashcash.com>
+=head2 L<http://www.hashcash.com>
 
 =head2 L<Crypt::HashCash>
 
